@@ -21,6 +21,7 @@ test_that("extract Arima objects from the stats package", {
 
 # forecast_ARIMA (forecast) ----
 test_that("extract forecast_ARIMA objects from the forecast package", {
+  testthat::skip_on_cran()
   skip_if_not_installed("forecast")
   require("forecast")
   set.seed(12345)
@@ -55,6 +56,7 @@ test_that("extract forecast_ARIMA objects from the forecast package", {
 
 # bife (bife) ----
 test_that("extract bife objects from the bife package", {
+  testthat::skip_on_cran()
   skip_if_not_installed("bife", minimum_version = "0.7")
   require("bife")
 
@@ -117,8 +119,26 @@ test_that("extract brmsfit objects from the brms package", {
   expect_equivalent(which(tr@gof.decimal), c(1:2, 4:5))
 })
 
+# clm (ordinal) ----
+test_that("extract clm objects from the ordinal package", {
+  testthat::skip_on_cran()
+  skip_if_not_installed("ordinal", minimum_version = "2019.12.10")
+  set.seed(12345)
+  fit <- ordinal::clm(Species ~ Sepal.Length, data = iris)
+  tr <- extract(fit)
+  expect_equivalent(tr@coef, c(3.452351, 18.569105, 21.689788), tolerance = 1e-2)
+  expect_equivalent(sum(tr@se), 5.331556, tolerance = 1e-2)
+  expect_equivalent(sum(tr@pvalues), 1.384519e-15, tolerance = 1e-2)
+  expect_equivalent(sum(tr@gof), 457.647, tolerance = 1e-2)
+  expect_length(tr@gof.names, 4)
+  expect_length(tr@coef, 3)
+  expect_equivalent(which(tr@pvalues < 0.05), 1:3)
+  expect_equivalent(which(tr@gof.decimal), 1:3)
+})
+
 # dynlm (dynlm) ----
 test_that("extract dynlm objects from the dynlm package", {
+  testthat::skip_on_cran()
   skip_if_not_installed("dynlm")
   skip_if_not_installed("datasets")
   require("dynlm")
@@ -139,6 +159,7 @@ test_that("extract dynlm objects from the dynlm package", {
 
 # feglm (alpaca) ----
 test_that("extract feglm objects from the alpaca package", {
+  testthat::skip_on_cran()
   skip_if_not_installed("alpaca", minimum_version = "0.3.2")
   require("alpaca")
 
@@ -160,6 +181,7 @@ test_that("extract feglm objects from the alpaca package", {
 
 # feis (feisr) ----
 test_that("extract feis objects from the feisr package", {
+  testthat::skip_on_cran()
   skip_if_not_installed("feisr", minimum_version = "1.0.1")
   require("feisr")
   set.seed(12345)
@@ -182,6 +204,7 @@ test_that("extract feis objects from the feisr package", {
 
 # felm (lfe) ----
 test_that("extract felm objects from the lfe package", {
+  testthat::skip_on_cran()
   skip_if_not_installed("lfe", minimum_version = "2.8.5")
   require("lfe")
 
@@ -215,6 +238,7 @@ test_that("extract felm objects from the lfe package", {
 
 # gamlssZadj (gamlss.inf) ----
 test_that("extract gamlssZadj objects from the gamlss.inf package", {
+  testthat::skip_on_cran()
   skip_if_not_installed("gamlss.inf", minimum_version = "1.0.1")
   require("gamlss.inf")
 
@@ -240,6 +264,7 @@ test_that("extract gamlssZadj objects from the gamlss.inf package", {
 
 # glm.cluster (miceadds) ----
 test_that("extract glm.cluster objects from the miceadds package", {
+  testthat::skip_on_cran()
   skip_if_not_installed("miceadds", minimum_version = "3.8.9")
   require("miceadds")
 
@@ -297,6 +322,7 @@ test_that("extract glmerMod objects from the lme4 package", {
 
 # glmmTMB (glmmTMB) ----
 test_that("extract glmmTMB objects from the glmmTMB package", {
+  testthat::skip_on_cran()
   skip_if_not_installed("glmmTMB", minimum_version = "1.0.1")
   require("glmmTMB")
 
@@ -328,6 +354,7 @@ test_that("extract glmmTMB objects from the glmmTMB package", {
 
 # ivreg (AER) ----
 test_that("extract ivreg objects from the AER package", {
+  testthat::skip_on_cran()
   skip_if_not_installed("AER")
   require("AER")
   set.seed(12345)
@@ -375,6 +402,7 @@ test_that("extract lm objects from the stats package", {
 
 # lm.cluster (miceadds) ----
 test_that("extract lm.cluster objects from the miceadds package", {
+  testthat::skip_on_cran()
   skip_if_not_installed("miceadds", minimum_version = "3.8.9")
   require("miceadds")
 
@@ -430,106 +458,83 @@ test_that("extract lmerMod objects from the lme4 package", {
   expect_length(which(grepl("Cov", tr2_wald@gof.names)), 0)
 })
 
-# multinom (nnet), mlogit (mlogit), mnlogit (mnlogit) ----
-test_that("extract multinom objects from the nnet package and mlogit and mnlogit objects", {
+test_that("extract multinom objects from the nnet package", {
   testthat::skip_on_cran()
-  testthat::skip_if_not_installed("carData", minimum_version = "3.0.2")
   testthat::skip_if_not_installed("nnet", minimum_version = "7.3.12")
   require("nnet")
-  set.seed(12345)
-  data(WVS, package = "carData")
-  WVS$poverty <- as.factor(as.character(WVS$poverty))
+
+  # example from https://thomasleeper.com/Rcourse/Tutorials/nominalglm.html
+  set.seed(100)
+  y <- sort(sample(1:3, 600, TRUE))
+  x <- numeric(length = 600)
+  x[1:200] <- -1 * x[1:200] + rnorm(200, 4, 2)
+  x[201:400] <- 1 * x[201:400] + rnorm(200)
+  x[401:600] <- 2 * x[401:600] + rnorm(200, 2, 2)
+
   sink("/dev/null")
-  model1 <- multinom(poverty ~ religion + degree + country + age + gender, data = WVS)
+  m1 <- multinom(y ~ x)
   sink()
-  tr1 <- extract(model1)
+  tr2 <- extract(m1, beside = FALSE)
+  tr3 <- extract(m1, beside = TRUE)
 
-  expect_equivalent(sum(abs(tr1@coef)), 8.387416, tolerance = 1e-2)
-  expect_equivalent(sum(tr1@se), 1.624519, tolerance = 1e-2)
-  expect_equivalent(sum(tr1@pvalues), 2.961305, tolerance = 1e-2)
-  expect_equivalent(sum(tr1@gof), 30608.87, tolerance = 1e-2)
-  expect_length(tr1@coef, 16)
-  expect_length(tr1@gof, 6)
-  expect_equivalent(which(tr1@gof.decimal), 1:4)
+  expect_equivalent(sum(abs(tr2@coef)), 6.845567, tolerance = 1e-2)
+  expect_equivalent(sum(tr2@se), 0.6671602, tolerance = 1e-2)
+  expect_equivalent(sum(tr2@pvalues), 1.677308e-16, tolerance = 1e-2)
+  expect_equivalent(sum(tr2@gof), 2852.451, tolerance = 1e-2)
+  expect_length(tr2@coef, 4)
+  expect_length(tr2@gof, 6)
+  expect_equivalent(which(tr2@gof.decimal), 1:4)
+  expect_equivalent(tr2@gof[6], 3)
+  expect_equal(dim(matrixreg(tr2)), c(15, 2))
+  expect_length(tr3, 2)
+  expect_length(tr3[[1]]@coef, 2)
+  expect_length(tr3[[2]]@coef, 2)
+})
 
-  tr1b <- extract(model1, beside = TRUE)
-  expect_type(tr1b, "list")
-  expect_length(tr1b, 2)
-  expect_equivalent(length(tr1b[[1]]@coef), length(tr1b[[1]]@coef))
-  expect_length(tr1b[[1]]@coef, 8)
-
-  testthat::skip_if_not_installed("MASS")
-  sink("/dev/null")
-  example(birthwt, package = "MASS")
-  bwt.mu <- multinom(low ~ ., bwt)
-  sink()
-  tr1c <- extract(bwt.mu)
-
-  expect_equivalent(sum(abs(tr1c@coef)), 8.117209, tolerance = 1e-2)
-  expect_equivalent(sum(tr1c@se), 5.314884, tolerance = 1e-2)
-  expect_equivalent(sum(tr1c@pvalues), 2.295426, tolerance = 1e-2)
-  expect_equivalent(sum(tr1c@gof), 759.248, tolerance = 1e-2)
-  expect_length(tr1c@coef, 11)
-  expect_length(tr1c@gof, 6)
-  expect_equivalent(which(tr1c@gof.decimal), 1:4)
-  expect_equivalent(tr1c@gof[6], 2)
-  expect_equal(dim(matrixreg(tr1c)), c(29, 2))
-
-  testthat::skip_if_not_installed("mlogit", minimum_version = "1.0.2")
+test_that("extract mlogit objects from the mlogit package", {
+  testthat::skip_if_not_installed("mlogit", minimum_version = "1.1.0")
   require("mlogit")
   set.seed(12345)
-  WVS2 <- mlogit.data(WVS, choice = "poverty", shape = "wide")
-  model2 <- mlogit(poverty ~ 0 | religion + degree + country +
-                     age + gender, data = WVS2)
-  tr2 <- extract(model2)
+  data("Fishing", package = "mlogit")
+  Fish <- dfidx(Fishing, varying = 2:9, shape = "wide", choice = "mode")
+  m <- mlogit(mode ~ price + catch | income, data = Fish)
+  tr1 <- extract(m)
 
-  expect_equivalent(sum(abs(tr1@coef)), sum(abs(tr2@coef)), tolerance = 1e-2)
-  expect_equivalent(sum(tr1@se), sum(tr2@se), tolerance = 1e-2)
-  expect_equivalent(sum(tr1@pvalues), sum(tr2@pvalues), tolerance = 1e-2)
-  expect_length(tr2@gof, 4)
-  expect_equivalent(which(tr2@gof.decimal), 1:2)
-
-  tr2b <- extract(model2, beside = TRUE)
-  expect_type(tr2b, "list")
-  expect_length(tr2b, 2)
-  expect_equivalent(length(tr2b[[1]]@coef), length(tr2b[[1]]@coef))
-  expect_length(tr2b[[1]]@coef, 8)
-
-  tr2c <- extract(model2, include.iterations = TRUE)
-  expect_length(tr2c@gof, 6)
-  expect_equivalent(which(tr2c@gof.decimal), c(1:2, 6))
+  expect_equivalent(sum(abs(tr1@coef)), 3.382753, tolerance = 1e-2)
+  expect_equivalent(sum(tr1@se), 0.7789933, tolerance = 1e-2)
+  expect_equivalent(sum(tr1@pvalues), 0.6136796, tolerance = 1e-2)
+  expect_equivalent(sum(tr1@gof), 2417.138, tolerance = 1e-2)
+  expect_length(tr1@coef, 8)
+  expect_length(tr1@gof, 4)
+  expect_equivalent(which(tr1@gof.decimal), 1:2)
+  expect_equivalent(tr1@gof[4], 4)
+  expect_equal(dim(matrixreg(tr1)), c(21, 2))
+  expect_warning(extract(m, beside = TRUE), "choice-specific covariates")
+})
 
+test_that("extract mnlogit models from the mnlogit package", {
   testthat::skip_if_not_installed("mnlogit", minimum_version = "1.2.6")
   require("mnlogit")
   set.seed(12345)
-  model3 <- mnlogit(poverty ~ 1 | religion + degree +
-                      country + age + gender, data = WVS2)
-  tr3 <- extract(model3)
+  data(Fish, package = "mnlogit")
+  fit <- mnlogit(mode ~ price | income | catch, Fish, ncores = 1)
+  tr <- extract(fit)
 
-  expect_equivalent(sum(abs(tr3@coef)), sum(abs(tr2@coef)), tolerance = 1e-2)
-  expect_equivalent(sum(tr3@se), sum(tr2@se), tolerance = 1e-2)
-  expect_equivalent(sum(tr3@pvalues), sum(tr2@pvalues), tolerance = 1e-2)
-  expect_length(tr3@gof, 4)
-  expect_equivalent(which(tr3@gof.decimal), 1:2)
-
-  tr3b <- extract(model3, beside = TRUE)
-  expect_type(tr3b, "list")
-  expect_length(tr3b, 2)
-  expect_equivalent(length(tr3b[[1]]@coef), length(tr3b[[1]]@coef))
-  expect_length(tr3b[[1]]@coef, 8)
-
-  tr3c <- extract(model3, include.iterations = TRUE)
-  expect_length(tr3c@gof, 7)
-  expect_equivalent(which(tr3c@gof.decimal), c(1:2, 6:7))
-
-  mr1 <- matrixreg(list(model1, model2, model3))
-  expect_equivalent(dim(mr1), c(103, 4))
-  mr2 <- matrixreg(list(model1, model2, model3), beside = TRUE)
-  expect_equivalent(dim(mr2), c(25, 7))
+  expect_equivalent(sum(abs(tr@coef)), 13.33618, tolerance = 1e-2)
+  expect_equivalent(sum(tr@se), 3.059299, tolerance = 1e-2)
+  expect_equivalent(sum(tr@pvalues), 0.4701358, tolerance = 1e-2)
+  expect_equivalent(sum(tr@gof), 2407.143, tolerance = 1e-2)
+  expect_length(tr@coef, 11)
+  expect_length(tr@gof, 4)
+  expect_equivalent(which(tr@gof.decimal), 1:2)
+  expect_equivalent(tr@gof[4], 4)
+  expect_equal(dim(matrixreg(tr)), c(27, 2))
+  expect_warning(extract(fit, beside = TRUE), "choice-specific covariates")
 })
 
 # nlmerMod (lme4) ----
 test_that("extract nlmerMod objects from the lme4 package", {
+  testthat::skip_on_cran()
   skip_if_not_installed("lme4")
   require("lme4")
   set.seed(12345)
@@ -556,6 +561,7 @@ test_that("extract nlmerMod objects from the lme4 package", {
 
 # speedglm (speedglm) ----
 test_that("extract speedglm objects from the speedglm package", {
+  testthat::skip_on_cran()
   skip_if_not_installed("speedglm", minimum_version = "0.3.2")
   require("speedglm")
   set.seed(12345)
@@ -577,6 +583,7 @@ test_that("extract speedglm objects from the speedglm package", {
 
 # speedlm (speedglm) ----
 test_that("extract speedlm objects from the speedglm package", {
+  testthat::skip_on_cran()
   skip_if_not_installed("speedglm", minimum_version = "0.3.2")
   require("speedglm")
   set.seed(12345)
